pub fn bind_checks(
catalog: &Catalog,
parameters: &Parameters,
session: &Session,
name: &QualifiedName,
) -> Result<Option<Checks>>Expand description
The CHECK constraints of a table as the query a write runs over the rows it wrote, or None
for a table with none.
Errors
If the name does not resolve to a table or a constraint no longer binds against it.