bind_with

Function bind_with 

pub fn bind_with(
    ast: &Ast,
    catalog: &Catalog,
    parameters: &Parameters,
) -> Result<Plan>
Binds a parsed query against a catalog, with values for its parameters.

Errors

Everything bind reports, plus an error for a parameter that was given no value.